@@ -16,10 +16,14 @@
 
 from .services.cloud_deploy import CloudDeployAsyncClient, CloudDeployClient
 from .types.cloud_deploy import (
+    AbandonReleaseRequest,
+    AbandonReleaseResponse,
     AnthosCluster,
     ApproveRolloutRequest,
     ApproveRolloutResponse,
     BuildArtifact,
+    CloudRunLocation,
+    CloudRunMetadata,
     Config,
     CreateDeliveryPipelineRequest,
     CreateReleaseRequest,
@@ -29,39 +33,57 @@ from .types.cloud_deploy import (
     DeleteDeliveryPipelineRequest,
     DeleteTargetRequest,
     DeliveryPipeline,
+    DeployJob,
+    DeployJobRun,
+    DeployJobRunMetadata,
+    DeploymentJobs,
     ExecutionConfig,
     GetConfigRequest,
     GetDeliveryPipelineRequest,
+    GetJobRunRequest,
     GetReleaseRequest,
     GetRolloutRequest,
     GetTargetRequest,
     GkeCluster,
+    Job,
+    JobRun,
     ListDeliveryPipelinesRequest,
     ListDeliveryPipelinesResponse,
+    ListJobRunsRequest,
+    ListJobRunsResponse,
     ListReleasesRequest,
     ListReleasesResponse,
     ListRolloutsRequest,
     ListRolloutsResponse,
     ListTargetsRequest,
     ListTargetsResponse,
+    Metadata,
     OperationMetadata,
+    Phase,
     PipelineCondition,
     PipelineReadyCondition,
     PrivatePool,
     Release,
+    RetryJobRequest,
+    RetryJobResponse,
     Rollout,
     SerialPipeline,
     SkaffoldVersion,
     Stage,
+    Standard,
+    Strategy,
     Target,
     TargetArtifact,
     TargetsPresentCondition,
     UpdateDeliveryPipelineRequest,
     UpdateTargetRequest,
+    VerifyJob,
+    VerifyJobRun,
 )
 from .types.deliverypipeline_notification_payload import (
     DeliveryPipelineNotificationEvent,
 )
+from .types.jobrun_notification_payload import JobRunNotificationEvent
 from .types.log_enums import Type
 from .types.release_notification_payload import ReleaseNotificationEvent
 from .types.release_render_payload import ReleaseRenderEvent
@@ -70,11 +92,15 @@ from .types.target_notification_payload import TargetNotificationEvent
 
 __all__ = (
     "CloudDeployAsyncClient",
+    "AbandonReleaseRequest",
+    "AbandonReleaseResponse",
     "AnthosCluster",
     "ApproveRolloutRequest",
     "ApproveRolloutResponse",
     "BuildArtifact",
     "CloudDeployClient",
+    "CloudRunLocation",
+    "CloudRunMetadata",
     "Config",
     "CreateDeliveryPipelineRequest",
     "CreateReleaseRequest",
@@ -85,33 +111,49 @@ __all__ = (
     "DeleteTargetRequest",
     "DeliveryPipeline",
     "DeliveryPipelineNotificationEvent",
+    "DeployJob",
+    "DeployJobRun",
+    "DeployJobRunMetadata",
+    "DeploymentJobs",
     "ExecutionConfig",
     "GetConfigRequest",
     "GetDeliveryPipelineRequest",
+    "GetJobRunRequest",
     "GetReleaseRequest",
     "GetRolloutRequest",
     "GetTargetRequest",
     "GkeCluster",
+    "Job",
+    "JobRun",
+    "JobRunNotificationEvent",
     "ListDeliveryPipelinesRequest",
     "ListDeliveryPipelinesResponse",
+    "ListJobRunsRequest",
+    "ListJobRunsResponse",
     "ListReleasesRequest",
     "ListReleasesResponse",
     "ListRolloutsRequest",
     "ListRolloutsResponse",
     "ListTargetsRequest",
     "ListTargetsResponse",
+    "Metadata",
     "OperationMetadata",
+    "Phase",
     "PipelineCondition",
     "PipelineReadyCondition",
     "PrivatePool",
     "Release",
     "ReleaseNotificationEvent",
     "ReleaseRenderEvent",
+    "RetryJobRequest",
+    "RetryJobResponse",
     "Rollout",
     "RolloutNotificationEvent",
     "SerialPipeline",
     "SkaffoldVersion",
     "Stage",
+    "Standard",
+    "Strategy",
     "Target",
     "TargetArtifact",
     "TargetNotificationEvent",
@@ -119,4 +161,6 @@ __all__ = (
     "Type",
     "UpdateDeliveryPipelineRequest",
     "UpdateTargetRequest",
+    "VerifyJob",
+    "VerifyJobRun",
 )
