@@ -537,3 +537,131 @@ class ListRolloutsAsyncPager:
 
     def __repr__(self) -> str:
         return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListJobRunsPager:
+    """A pager for iterating through ``list_job_runs`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.deploy_v1.types.ListJobRunsResponse` object, and
+    provides an ``__iter__`` method to iterate through its
+    ``job_runs`` field.
+
+    If there are more pages, the ``__iter__`` method will make additional
+    ``ListJobRuns`` requests and continue to iterate
+    through the ``job_runs`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.deploy_v1.types.ListJobRunsResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., cloud_deploy.ListJobRunsResponse],
+        request: cloud_deploy.ListJobRunsRequest,
+        response: cloud_deploy.ListJobRunsResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiate the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.deploy_v1.types.ListJobRunsRequest):
+                The initial request object.
+            response (google.cloud.deploy_v1.types.ListJobRunsResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = cloud_deploy.ListJobRunsRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    def pages(self) -> Iterator[cloud_deploy.ListJobRunsResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __iter__(self) -> Iterator[cloud_deploy.JobRun]:
+        for page in self.pages:
+            yield from page.job_runs
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListJobRunsAsyncPager:
+    """A pager for iterating through ``list_job_runs`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.deploy_v1.types.ListJobRunsResponse` object, and
+    provides an ``__aiter__`` method to iterate through its
+    ``job_runs`` field.
+
+    If there are more pages, the ``__aiter__`` method will make additional
+    ``ListJobRuns`` requests and continue to iterate
+    through the ``job_runs`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.deploy_v1.types.ListJobRunsResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., Awaitable[cloud_deploy.ListJobRunsResponse]],
+        request: cloud_deploy.ListJobRunsRequest,
+        response: cloud_deploy.ListJobRunsResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiates the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.deploy_v1.types.ListJobRunsRequest):
+                The initial request object.
+            response (google.cloud.deploy_v1.types.ListJobRunsResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = cloud_deploy.ListJobRunsRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    async def pages(self) -> AsyncIterator[cloud_deploy.ListJobRunsResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = await self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __aiter__(self) -> AsyncIterator[cloud_deploy.JobRun]:
+        async def async_generator():
+            async for page in self.pages:
+                for response in page.job_runs:
+                    yield response
+
+        return async_generator()
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
